"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai = require("chai");
var express = require("express");
var supertest = require("supertest");
var cookies_1 = require("./cookies");
var expect = chai.expect;
describe('@usvc/server/data/cookies', function () {
    var server;
    before(function () {
        server = express();
        server.use(cookies_1.createMiddleware());
    });
    context('issuing cookies', function () {
        var endpoint = '/_issue_cookies';
        before(function () {
            server.get(endpoint, function (req, res) {
                var views = req.session.views;
                req.session.issuedAt = (new Date()).toISOString();
                req.session.views = (views ? views : 0) + 1;
                res.json(req.session);
            });
        });
        it('issues correctly', function () {
            return supertest(server)
                .get(endpoint)
                .then(function (_a) {
                var header = _a.header;
                // tslint:disable-next-line no-unused-expression
                expect(header['set-cookie']).to.not.be.undefined;
            });
        });
        it('reads and re-issues correctly', function () {
            return supertest(server)
                .get(endpoint)
                .then(function (_a) {
                var header = _a.header;
                return header['set-cookie'];
            })
                .then(function (cookies) {
                return supertest(server)
                    .get(endpoint)
                    .set('Cookie', cookies);
            })
                .then(function (_a) {
                var body = _a.body;
                expect(body).to.have.property('views');
                expect(body.views).to.deep.equal(2);
            });
        });
    });
    context('parsing cookies', function () {
        var endpoint = '/_parse_cookies';
        before(function () {
            server.get(endpoint, function (req, res) {
                res.json(req.cookies);
            });
        });
        it('works correctly', function () {
            return supertest(server)
                .get(endpoint)
                .set('Cookie', [
                'hello=world',
                'one=1',
                'bool=true',
                '2=two',
            ].join(';'))
                .then(function (_a) {
                var body = _a.body;
                expect(body).to.have.property('hello');
                expect(body.hello).to.deep.equal('world');
                expect(body).to.have.property('one');
                expect(body.one).to.deep.equal('1');
                expect(body).to.have.property('bool');
                expect(body.bool).to.deep.equal('true');
                expect(body).to.have.property('2');
                expect(body['2']).to.deep.equal('two');
            });
        });
    });
    // / parsing cookies
});
//# sourceMappingURL=cookies.test.js.map