"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai = require("chai");
var express = require("express");
var supertest = require("supertest");
var url_encoded_1 = require("./url-encoded");
var expect = chai.expect;
describe('@usvc/server/data/url-encoded', function () {
    var server;
    before(function () {
        server = express();
        server.use(url_encoded_1.createMiddleware());
        server.post('/', function (req, res) {
            res.json(req.body);
        });
    });
    it('works', function () {
        return supertest(server)
            .post('/')
            .send({
            string: 'string',
            number: 1,
            float: 1.1234567,
            boolean: true,
            null: null,
            object: {
                hello: 'world',
            },
        })
            .set('Content-Type', 'application/x-www-form-urlencoded')
            .then(function (_a) {
            var body = _a.body;
            expect(body).to.have.keys([
                'boolean',
                'float',
                'number',
                'null',
                'object',
                'string',
            ]);
            expect(body.string).to.deep.equal('string');
            expect(body.number).to.deep.equal('1');
            expect(body.float).to.deep.equal('1.1234567');
            expect(body.boolean).to.deep.equal('true');
            expect(body.null).to.deep.equal('');
            expect(body.object).to.deep.equal({
                hello: 'world',
            });
        });
    });
});
//# sourceMappingURL=url-encoded.test.js.map