"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var express = require("express");
var data = require("./data");
var security = require("./security");
var observability = require("./observability");
function createServer(_a) {
    var _b = _a === void 0 ? {} : _a, _c = _b.enableCors, enableCors = _c === void 0 ? true : _c, _d = _b.enableCsp, enableCsp = _d === void 0 ? true : _d, _e = _b.enableCookies, enableCookies = _e === void 0 ? true : _e, _f = _b.enableJsonBody, enableJsonBody = _f === void 0 ? true : _f, _g = _b.enableMetrics, enableMetrics = _g === void 0 ? true : _g, _h = _b.enableUrlEncodedBody, enableUrlEncodedBody = _h === void 0 ? true : _h, cookies = _b.cookies, cors = _b.cors, csp = _b.csp, jsonBody = _b.jsonBody, metrics = _b.metrics, _j = _b.middlewares, middlewares = _j === void 0 ? {} : _j, _k = _b.logger, logger = _k === void 0 ? console : _k, urlEncodedBody = _b.urlEncodedBody;
    var app = express();
    var metricsComponent;
    // any pre-injection middlewares?
    if (middlewares.before && middlewares.before.length > 0) {
        middlewares.before.forEach(function (requestHandler) { return app.use(requestHandler); });
    }
    // standard http security - not an option
    app.use(security.http.createMiddleware());
    if (enableCors) {
        app.use(security.cors.createMiddleware(cors));
    }
    if (enableMetrics) {
        metricsComponent = observability.metrics.create({
            uri: '/metrics',
        });
        app.use(metricsComponent.getExpressMiddleware());
    }
    if (enableJsonBody) {
        app.use(data.json.createMiddleware(jsonBody));
    }
    if (enableUrlEncodedBody) {
        app.use(data.urlEncoded.createMiddleware(urlEncodedBody));
    }
    if (enableCookies) {
        app.use(data.cookies.createMiddleware(cookies));
    }
    if (enableCsp) {
        app.use(security.csp.createMiddleware(csp));
        security.csp.provisionCspReportingMiddleware(__assign({ application: app, logger: logger }, csp));
    }
    // any post-injection middlewares?
    if (middlewares.after && middlewares.after.length > 0) {
        middlewares.after.forEach(function (requestHandler) { return app.use(requestHandler); });
    }
    if (enableMetrics) {
        metricsComponent.provisionMetrics(app);
    }
    return app;
}
exports.createServer = createServer;
//# sourceMappingURL=index.js.map