"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai = require("chai");
var express = require("express");
var supertest = require("supertest");
var cors_1 = require("./cors");
var expect = chai.expect;
describe('@usvc/server/security/cors', function () {
    var server;
    var observed;
    before(function () {
        server = express();
        server.use(cors_1.createMiddleware({
            allowedHeaders: ['Authorization'],
            credentials: true,
            exposedHeaders: ['content-type'],
            maxAge: 1000 * 60,
            methods: ['GET'],
            urls: ['http://_test.website'],
        }));
        server.get('/', function (req, res) {
            res.json('ok');
        });
        return supertest(server)
            .options('/')
            .set('Origin', 'http://_test.website')
            .expect(200)
            .then(function (response) {
            observed = response['headers'];
        });
    });
    it('sets the credentials correctly', function () {
        expect(observed).to.have.property('access-control-allow-credentials');
        expect(observed['access-control-allow-credentials']).to.deep.equal('true');
    });
    it('sets the allowed headers', function () {
        expect(observed).to.have.property('access-control-allow-headers');
        expect(observed['access-control-allow-headers'])
            .to.deep.equal('Authorization');
    });
    it('sets the allowed methods', function () {
        expect(observed).to.have.property('access-control-allow-methods');
        expect(observed['access-control-allow-methods']).to.deep.equal('GET');
    });
    it('sets the allowed origin', function () {
        expect(observed).to.have.property('access-control-allow-origin');
        expect(observed['access-control-allow-origin'])
            .to.deep.equal('http://_test.website');
    });
    it('sets the max age', function () {
        expect(observed).to.have.property('access-control-max-age');
        expect(observed['access-control-max-age']).to.deep.equal('60000');
    });
});
//# sourceMappingURL=cors.test.js.map