"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var helmet = require("helmet");
function provisionCspReportingMiddleware(_a) {
    var _b = _a === void 0 ? {} : _a, application = _b.application, _c = _b.logger, logger = _c === void 0 ? console : _c, _d = _b.logLevel, logLevel = _d === void 0 ? 'warn' : _d, _e = _b.reportUri, reportUri = _e === void 0 ? '/csp-report' : _e;
    if (!application) {
        // tslint:disable-next-line max-line-length
        throw new Error(':application needs to be defined to provision a CSP reporter endpoint.');
    }
    if (typeof logger[logLevel] !== 'function') {
        // tslint:disable-next-line max-line-length
        throw new Error(":logLevel \"" + logLevel + "\" was not found in the provided :logger.");
    }
    application.post(reportUri, function (req, res) {
        if (req.body) {
            logger[logLevel]({
                message: 'CSP violation reported',
                data: req.body,
            });
        }
        else {
            logger[logLevel]({
                message: 'CSP violation reported with no data',
                data: null,
            });
        }
        res.status(204).send();
    });
}
exports.provisionCspReportingMiddleware = provisionCspReportingMiddleware;
function createMiddleware(_a) {
    var _b = _a === void 0 ? {} : _a, _c = _b.childSrc, childSrc = _c === void 0 ? ['"self"'] : _c, _d = _b.connectSrc, connectSrc = _d === void 0 ? ['"self"'] : _d, _e = _b.defaultSrc, defaultSrc = _e === void 0 ? ['"self"'] : _e, _f = _b.disableAndroid, disableAndroid = _f === void 0 ? false : _f, _g = _b.fontSrc, fontSrc = _g === void 0 ? ['"self"'] : _g, _h = _b.imgSrc, imgSrc = _h === void 0 ? ['"self"'] : _h, _j = _b.objectSrc, objectSrc = _j === void 0 ? ['"none"'] : _j, _k = _b.reportUri, reportUri = _k === void 0 ? '/csp-report' : _k, _l = _b.sandbox, sandbox = _l === void 0 ? ['allow-forms', 'allow-scripts'] : _l, _m = _b.scriptSrc, scriptSrc = _m === void 0 ? ['"self"'] : _m, _o = _b.styleSrc, styleSrc = _o === void 0 ? ['"self"'] : _o;
    return helmet.contentSecurityPolicy({
        directives: {
            childSrc: childSrc,
            connectSrc: connectSrc,
            defaultSrc: defaultSrc,
            fontSrc: fontSrc,
            imgSrc: imgSrc,
            objectSrc: objectSrc,
            reportUri: reportUri,
            sandbox: sandbox,
            scriptSrc: scriptSrc,
            styleSrc: styleSrc,
        },
        disableAndroid: disableAndroid,
        browserSniff: true,
    });
}
exports.createMiddleware = createMiddleware;
//# sourceMappingURL=csp.js.map