"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai = require("chai");
var sinon = require("sinon");
var sinonChai = require("sinon-chai");
var express = require("express");
var supertest = require("supertest");
var csp_1 = require("./csp");
chai.use(sinonChai);
var expect = chai.expect;
describe('@usvc/server/security/csp', function () {
    var logger = {
        info: null,
    };
    var observed = {
        cspHeaders: null,
        cspReportResponse: null,
    };
    var server;
    before(function () {
        logger.info = sinon.spy();
        server = express();
        server.use(csp_1.createMiddleware({
            childSrc: ['http://test.child-src.com'],
            connectSrc: ['http://test.connect-src.com'],
            defaultSrc: ['http://test.default-src.com'],
            fontSrc: ['http://test.font-src.com'],
            imgSrc: ['http://test.img-src.com'],
            objectSrc: ['http://test.object-src.com'],
            reportUri: '/__report_csp_uri',
            scriptSrc: ['http://test.script-src.com'],
            styleSrc: ['http://test.style-src.com'],
        }));
        csp_1.provisionCspReportingMiddleware({
            application: server,
            reportUri: '/__report_csp_url',
            logger: logger,
            logLevel: 'info',
        });
        return Promise.all([
            supertest(server)
                .get('/')
                .then(function (_a) {
                var header = _a.header;
                observed.cspHeaders = header;
            }),
            supertest(server)
                .post('/__report_csp_url')
                .send({ hello: 'world' })
                .then(function (response) {
                observed.cspReportResponse = response;
            }),
        ]);
    });
    context('CSP headers', function () {
        var cspHeaders;
        before(function () {
            cspHeaders = observed.cspHeaders['x-content-security-policy'];
        });
        it('sets child-src', function () {
            expect(cspHeaders).to.contain('child-src http://test.child-src.com');
        });
        it('sets connect-src', function () {
            expect(cspHeaders).to.contain('connect-src http://test.connect-src.com');
        });
        it('sets default-src', function () {
            expect(cspHeaders).to.contain('default-src http://test.default-src.com');
        });
        it('sets font-src', function () {
            expect(cspHeaders).to.contain('font-src http://test.font-src.com');
        });
        it('sets img-src', function () {
            expect(cspHeaders).to.contain('img-src http://test.img-src.com');
        });
        it('sets object-src', function () {
            expect(cspHeaders).to.contain('object-src http://test.object-src.com');
        });
        it('sets script-src', function () {
            expect(cspHeaders).to.contain('script-src http://test.script-src.com');
        });
        it('sets style-src', function () {
            expect(cspHeaders).to.contain('style-src http://test.style-src.com');
        });
        it('sets the report-uri', function () {
            expect(cspHeaders).to.contain('report-uri /__report_csp_uri');
        });
        it('sets the sandbox', function () {
            expect(cspHeaders).to.contain('sandbox allow-forms allow-scripts');
        });
    });
    // / CSP headers
    context('CSP reporter', function () {
        var cspReportResponse;
        before(function () {
            cspReportResponse = observed.cspReportResponse;
        });
        it('works as expected', function () {
            expect(cspReportResponse.status).to.deep.equal(204);
        });
    });
    // / CSP reporter
});
//# sourceMappingURL=csp.test.js.map