"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai = require("chai");
var express = require("express");
var supertest = require("supertest");
var http_1 = require("./http");
var expect = chai.expect;
describe('@usvc/server/security/http', function () {
    var server;
    var observed;
    before(function () {
        server = express();
        server.use(http_1.createMiddleware());
        server.get('/', function (req, res) {
            res.json('ok');
        });
        return supertest(server)
            .get('/')
            .expect(200)
            .then(function (response) {
            observed = response['headers'];
        });
    });
    it('hides any indication of express', function () {
        Object.keys(observed).forEach(function (header) {
            expect(header).to.not.match(/(e|E)xpress/);
            expect(observed[header]).to.not.match(/(e|E)xpress/);
        });
    });
    it('denies browser dns prefetching', function () {
        expect(observed).to.have.property('x-dns-prefetch-control');
        expect(observed['x-dns-prefetch-control']).to.equal('off');
    });
    it('prevents clickjacking', function () {
        expect(observed).to.have.property('x-frame-options');
        expect(observed['x-frame-options']).to.equal('SAMEORIGIN');
    });
    it('implements HTTP strict transport security', function () {
        expect(observed).to.have.property('strict-transport-security');
        expect(observed['strict-transport-security'])
            .to.equal('max-age=15552000; includeSubDomains');
    });
    it('sets download options for IE8+', function () {
        expect(observed).to.have.property('x-download-options');
        expect(observed['x-download-options']).to.equal('noopen');
    });
    it('stops page from loading when XSS is detected', function () {
        expect(observed).to.have.property('x-xss-protection');
        expect(observed['x-xss-protection']).to.equal('1; mode=block');
    });
    it('disables browser-side caching', function () {
        expect(observed).to.have.property('cache-control');
        expect(observed['cache-control'])
            .to.equal('no-store, no-cache, must-revalidate, proxy-revalidate');
        expect(observed).to.have.property('expires');
        expect(observed['expires']).to.equal('0');
        expect(observed).to.have.property('pragma');
        expect(observed['pragma']).to.equal('no-cache');
        expect(observed).to.have.property('surrogate-control');
        expect(observed['surrogate-control']).to.equal('no-store');
    });
});
//# sourceMappingURL=http.test.js.map